function [iWorst,worstValue] = findWorst(allData,options)
% FINDWORST  Locates the worst iteration in a set of results generated 
% by WORSTCASE.
% 
%   [I,VALUE] = findWorst(DATASTRUCT,OPTIONS)  DATASTRUCT a set of results
%   generated by WORSTCASE and OPTIONS is a WCOPTIONS object used by 
%   WORSTCASE.  FINDWORST locates the iterate of the worst iteration and
%   reports the value of that iteration.  The value is evaluated according
%   to OPTIONS.Objective, which is the name of the output norm that was 
%   maximized by WORSTCASE ('L2' or 'LInfinity').
% 
%   See also WORSTCASE, WCOPTIONS.

if ~isstruct(allData)
    error('Input must be a structure array')
end
if ~isa(options,'wcoptions')
    error('Second input argument must be a wcoptions object')
end

worstValue = 0;
for i = 1:length(allData)
    t = allData(i).time;
    y = allData(i).output;
    switch options.Objective
        case 'L2'
            value = get2norm(y,t);
        case 'LInfinity'
            for j = 1:size(y,1);
                L(j) = y(j,:)*y(j,:)';
            end
            value = max(L);
        otherwise
            error('Invalid objective');
    end
    if value >= worstValue
        iWorst = i;
        worstValue = value;
    end
end
    
worstInput = allData(iWorst).input;
worstTime = allData(iWorst).time;
validInput = abs( get2norm(worstInput,worstTime) - sqrt(options.R) ) <= options.Tol;
if ~validInput
    warning('L2-norm of the worst input does not match the limit specified in wcoptions object.')
end
